
// There are 3 shaders in this .glsl file
//  
//  1. vertexShader_Perspective
//  2. fragmentShader_Perspective
//  3. vertexShader_NoPerspective
//  3. fragmentShader_NoPerspective
//  4. fragmentShader_Black
//
// First shader program is formed from shaders 1 and 2.
// Second shader program is formed from shaders 3 and 4.
// Third shader program formed from shaders 1 and 5
//
// The first two fragment shaders (2. and 4.) procedurally generate
//    a black and white checkboard texture map
// 
// Author: Sam Buss, sbuss@ucsd.edu.
// Last updated 2/28/2020.

// ***************************
#beginglsl vertexshader vertexShader_Perspective
#version 330 core
layout (location = 0) in vec3 vPos;	       // Position in attribute location 0
layout (location = 1) in vec2 vTexCoords;  // Texture coordinates in attribute location 1
  
out vec2 theTexCoords;                 // Output Texture Coordinates to the fragment shader    
uniform mat4 projectionMatrix;         // The projection matrix    
uniform mat4 modelviewMatrix;          // The model-view matrix    
void main()    
{    
   gl_Position = projectionMatrix * modelviewMatrix * vec4(vPos.x, vPos.y, vPos.z, 1.0);    
   theTexCoords = vTexCoords;    
}
#endglsl 

#beginglsl vertexshader vertexShader_NoPerspective
#version 330 core
layout (location = 0) in vec3 vPos;	       // Position in attribute location 0
layout (location = 1) in vec2 vTexCoords;  // Texture coordinates in attribute location 1
  
noperspective out vec2 theTexCoords;   // Output Texture Coordinates to the fragment shader    
uniform mat4 projectionMatrix;         // The projection matrix    
uniform mat4 modelviewMatrix;          // The model-view matrix    
void main()    
{    
   gl_Position = projectionMatrix * modelviewMatrix * vec4(vPos.x, vPos.y, vPos.z, 1.0);    
   theTexCoords = vTexCoords;    
}
#endglsl 

// ***************************
#beginglsl fragmentshader fragmentShader_Perspective
#version 330 core    
in vec2 theTexCoords;    // Color value came from the vertex shader (shaded)     
out vec4 FragColor;      // Color that will be used for the fragment    
void main()    
{    
   int resolution = 10;
   int i =  int(floor(theTexCoords.x*resolution));
   int j =  int(floor(theTexCoords.y*resolution));
   if ( (i+j)%2 == 0 ) {
     FragColor = vec4(0.0, 0.0, 0.0, 1.0);      // Black
   }
   else {
      FragColor = vec4(1.0, 1.0, 1.0, 1.0);     // White
   }
}
#endglsl

// ***************************
#beginglsl fragmentshader fragmentShader_NoPerspective
#version 330 core    
noperspective in vec2 theTexCoords;   // Color value came from the vertex shader (shaded)     
out vec4 FragColor;                   // Color that will be used for the fragment    
void main()    
{    
   int resolution = 10;
   int i =  int(floor(theTexCoords.x*resolution));
   int j =  int(floor(theTexCoords.y*resolution));
   if ( (i+j)%2 == 0 ) {
     FragColor = vec4(0.0, 0.0, 0.0, 1.0);      // Black
   }
   else {
      FragColor = vec4(1.0, 1.0, 1.0, 1.0);     // White
   }
}
#endglsl

// ***************************
// Use this fragment shader to render lines
#beginglsl fragmentshader fragmentShader_Black
#version 330 core    
out vec4 FragColor;      // Color that will be used for the fragment    
void main()    
{    
   FragColor = vec4(0.0, 0.0, 0.0, 1.0);     // Black
}
#endglsl

